# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetVpcFirewallControlPoliciesResult',
    'AwaitableGetVpcFirewallControlPoliciesResult',
    'get_vpc_firewall_control_policies',
    'get_vpc_firewall_control_policies_output',
]

@pulumi.output_type
class GetVpcFirewallControlPoliciesResult:
    """
    A collection of values returned by getVpcFirewallControlPolicies.
    """
    def __init__(__self__, acl_action=None, acl_uuid=None, description=None, destination=None, id=None, ids=None, lang=None, member_uid=None, output_file=None, page_number=None, page_size=None, policies=None, proto=None, release=None, source=None, vpc_firewall_id=None):
        if acl_action and not isinstance(acl_action, str):
            raise TypeError("Expected argument 'acl_action' to be a str")
        pulumi.set(__self__, "acl_action", acl_action)
        if acl_uuid and not isinstance(acl_uuid, str):
            raise TypeError("Expected argument 'acl_uuid' to be a str")
        pulumi.set(__self__, "acl_uuid", acl_uuid)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if destination and not isinstance(destination, str):
            raise TypeError("Expected argument 'destination' to be a str")
        pulumi.set(__self__, "destination", destination)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if lang and not isinstance(lang, str):
            raise TypeError("Expected argument 'lang' to be a str")
        pulumi.set(__self__, "lang", lang)
        if member_uid and not isinstance(member_uid, str):
            raise TypeError("Expected argument 'member_uid' to be a str")
        pulumi.set(__self__, "member_uid", member_uid)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if proto and not isinstance(proto, str):
            raise TypeError("Expected argument 'proto' to be a str")
        pulumi.set(__self__, "proto", proto)
        if release and not isinstance(release, bool):
            raise TypeError("Expected argument 'release' to be a bool")
        pulumi.set(__self__, "release", release)
        if source and not isinstance(source, str):
            raise TypeError("Expected argument 'source' to be a str")
        pulumi.set(__self__, "source", source)
        if vpc_firewall_id and not isinstance(vpc_firewall_id, str):
            raise TypeError("Expected argument 'vpc_firewall_id' to be a str")
        pulumi.set(__self__, "vpc_firewall_id", vpc_firewall_id)

    @property
    @pulumi.getter(name="aclAction")
    def acl_action(self) -> Optional[str]:
        return pulumi.get(self, "acl_action")

    @property
    @pulumi.getter(name="aclUuid")
    def acl_uuid(self) -> Optional[str]:
        return pulumi.get(self, "acl_uuid")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def destination(self) -> Optional[str]:
        return pulumi.get(self, "destination")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def lang(self) -> Optional[str]:
        return pulumi.get(self, "lang")

    @property
    @pulumi.getter(name="memberUid")
    def member_uid(self) -> Optional[str]:
        return pulumi.get(self, "member_uid")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetVpcFirewallControlPoliciesPolicyResult']:
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter
    def proto(self) -> Optional[str]:
        return pulumi.get(self, "proto")

    @property
    @pulumi.getter
    def release(self) -> Optional[bool]:
        return pulumi.get(self, "release")

    @property
    @pulumi.getter
    def source(self) -> Optional[str]:
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="vpcFirewallId")
    def vpc_firewall_id(self) -> str:
        return pulumi.get(self, "vpc_firewall_id")


class AwaitableGetVpcFirewallControlPoliciesResult(GetVpcFirewallControlPoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpcFirewallControlPoliciesResult(
            acl_action=self.acl_action,
            acl_uuid=self.acl_uuid,
            description=self.description,
            destination=self.destination,
            id=self.id,
            ids=self.ids,
            lang=self.lang,
            member_uid=self.member_uid,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            policies=self.policies,
            proto=self.proto,
            release=self.release,
            source=self.source,
            vpc_firewall_id=self.vpc_firewall_id)


def get_vpc_firewall_control_policies(acl_action: Optional[str] = None,
                                      acl_uuid: Optional[str] = None,
                                      description: Optional[str] = None,
                                      destination: Optional[str] = None,
                                      ids: Optional[Sequence[str]] = None,
                                      lang: Optional[str] = None,
                                      member_uid: Optional[str] = None,
                                      output_file: Optional[str] = None,
                                      page_number: Optional[int] = None,
                                      page_size: Optional[int] = None,
                                      proto: Optional[str] = None,
                                      release: Optional[bool] = None,
                                      source: Optional[str] = None,
                                      vpc_firewall_id: Optional[str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVpcFirewallControlPoliciesResult:
    """
    This data source provides the Cloud Firewall Vpc Firewall Control Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.194.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cloudfirewall.get_vpc_firewall_control_policies(vpc_firewall_id="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ])
    pulumi.export("alicloudCloudFirewallVpcFirewallControlPoliciesId1", ids.policies[0].id)
    ```


    :param str acl_action: Access control over VPC firewalls are set in the access traffic via Alibaba cloud firewall way (ACT).
    :param str acl_uuid: Access control over VPC firewalls strategy unique identifier.
    :param str description: Access control over VPC firewalls description of the strategy information.
    :param str destination: Access control over VPC firewalls strategy the destination address in.
    :param Sequence[str] ids: A list of Vpc Firewall Control Policy IDs.
    :param str lang: The language of the content within the request and response. Valid values: `zh`, `en`.
    :param str member_uid: The UID of the member account of the current Alibaba cloud account.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str proto: Access control over VPC firewalls strategy access traffic of the protocol type.
    :param bool release: The enabled status of the access control policy. The policy is enabled by default after it is created. Value:
    :param str source: Access control over VPC firewalls strategy in the source address.
    :param str vpc_firewall_id: The ID of the VPC firewall instance.
    """
    __args__ = dict()
    __args__['aclAction'] = acl_action
    __args__['aclUuid'] = acl_uuid
    __args__['description'] = description
    __args__['destination'] = destination
    __args__['ids'] = ids
    __args__['lang'] = lang
    __args__['memberUid'] = member_uid
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['proto'] = proto
    __args__['release'] = release
    __args__['source'] = source
    __args__['vpcFirewallId'] = vpc_firewall_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cloudfirewall/getVpcFirewallControlPolicies:getVpcFirewallControlPolicies', __args__, opts=opts, typ=GetVpcFirewallControlPoliciesResult).value

    return AwaitableGetVpcFirewallControlPoliciesResult(
        acl_action=pulumi.get(__ret__, 'acl_action'),
        acl_uuid=pulumi.get(__ret__, 'acl_uuid'),
        description=pulumi.get(__ret__, 'description'),
        destination=pulumi.get(__ret__, 'destination'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        lang=pulumi.get(__ret__, 'lang'),
        member_uid=pulumi.get(__ret__, 'member_uid'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        policies=pulumi.get(__ret__, 'policies'),
        proto=pulumi.get(__ret__, 'proto'),
        release=pulumi.get(__ret__, 'release'),
        source=pulumi.get(__ret__, 'source'),
        vpc_firewall_id=pulumi.get(__ret__, 'vpc_firewall_id'))


@_utilities.lift_output_func(get_vpc_firewall_control_policies)
def get_vpc_firewall_control_policies_output(acl_action: Optional[pulumi.Input[Optional[str]]] = None,
                                             acl_uuid: Optional[pulumi.Input[Optional[str]]] = None,
                                             description: Optional[pulumi.Input[Optional[str]]] = None,
                                             destination: Optional[pulumi.Input[Optional[str]]] = None,
                                             ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                             lang: Optional[pulumi.Input[Optional[str]]] = None,
                                             member_uid: Optional[pulumi.Input[Optional[str]]] = None,
                                             output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                             page_number: Optional[pulumi.Input[Optional[int]]] = None,
                                             page_size: Optional[pulumi.Input[Optional[int]]] = None,
                                             proto: Optional[pulumi.Input[Optional[str]]] = None,
                                             release: Optional[pulumi.Input[Optional[bool]]] = None,
                                             source: Optional[pulumi.Input[Optional[str]]] = None,
                                             vpc_firewall_id: Optional[pulumi.Input[str]] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVpcFirewallControlPoliciesResult]:
    """
    This data source provides the Cloud Firewall Vpc Firewall Control Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.194.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cloudfirewall.get_vpc_firewall_control_policies(vpc_firewall_id="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ])
    pulumi.export("alicloudCloudFirewallVpcFirewallControlPoliciesId1", ids.policies[0].id)
    ```


    :param str acl_action: Access control over VPC firewalls are set in the access traffic via Alibaba cloud firewall way (ACT).
    :param str acl_uuid: Access control over VPC firewalls strategy unique identifier.
    :param str description: Access control over VPC firewalls description of the strategy information.
    :param str destination: Access control over VPC firewalls strategy the destination address in.
    :param Sequence[str] ids: A list of Vpc Firewall Control Policy IDs.
    :param str lang: The language of the content within the request and response. Valid values: `zh`, `en`.
    :param str member_uid: The UID of the member account of the current Alibaba cloud account.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str proto: Access control over VPC firewalls strategy access traffic of the protocol type.
    :param bool release: The enabled status of the access control policy. The policy is enabled by default after it is created. Value:
    :param str source: Access control over VPC firewalls strategy in the source address.
    :param str vpc_firewall_id: The ID of the VPC firewall instance.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetNetworkAclsResult',
    'AwaitableGetNetworkAclsResult',
    'get_network_acls',
    'get_network_acls_output',
]

@pulumi.output_type
class GetNetworkAclsResult:
    """
    A collection of values returned by getNetworkAcls.
    """
    def __init__(__self__, acls=None, id=None, ids=None, name_regex=None, names=None, network_acl_name=None, output_file=None, resource_id=None, resource_type=None, status=None, vpc_id=None):
        if acls and not isinstance(acls, list):
            raise TypeError("Expected argument 'acls' to be a list")
        pulumi.set(__self__, "acls", acls)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if network_acl_name and not isinstance(network_acl_name, str):
            raise TypeError("Expected argument 'network_acl_name' to be a str")
        pulumi.set(__self__, "network_acl_name", network_acl_name)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if resource_id and not isinstance(resource_id, str):
            raise TypeError("Expected argument 'resource_id' to be a str")
        pulumi.set(__self__, "resource_id", resource_id)
        if resource_type and not isinstance(resource_type, str):
            raise TypeError("Expected argument 'resource_type' to be a str")
        pulumi.set(__self__, "resource_type", resource_type)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter
    def acls(self) -> Sequence['outputs.GetNetworkAclsAclResult']:
        return pulumi.get(self, "acls")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="networkAclName")
    def network_acl_name(self) -> Optional[str]:
        return pulumi.get(self, "network_acl_name")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[str]:
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[str]:
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[str]:
        return pulumi.get(self, "vpc_id")


class AwaitableGetNetworkAclsResult(GetNetworkAclsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkAclsResult(
            acls=self.acls,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            network_acl_name=self.network_acl_name,
            output_file=self.output_file,
            resource_id=self.resource_id,
            resource_type=self.resource_type,
            status=self.status,
            vpc_id=self.vpc_id)


def get_network_acls(ids: Optional[Sequence[str]] = None,
                     name_regex: Optional[str] = None,
                     network_acl_name: Optional[str] = None,
                     output_file: Optional[str] = None,
                     resource_id: Optional[str] = None,
                     resource_type: Optional[str] = None,
                     status: Optional[str] = None,
                     vpc_id: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkAclsResult:
    """
    This data source provides the Network Acls of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.122.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.vpc.get_network_acls(ids=["example_value"],
        name_regex="the_resource_name")
    pulumi.export("firstNetworkAclId", example.acls[0].id)
    ```


    :param Sequence[str] ids: A list of Network Acl ID.
    :param str name_regex: A regex string to filter results by Network Acl name.
    :param str network_acl_name: The name of the network ACL.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_id: The ID of the associated resource.
    :param str resource_type: The type of the associated resource.
    :param str status: The state of the network ACL.
    :param str vpc_id: The ID of the associated VPC.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['networkAclName'] = network_acl_name
    __args__['outputFile'] = output_file
    __args__['resourceId'] = resource_id
    __args__['resourceType'] = resource_type
    __args__['status'] = status
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getNetworkAcls:getNetworkAcls', __args__, opts=opts, typ=GetNetworkAclsResult).value

    return AwaitableGetNetworkAclsResult(
        acls=pulumi.get(__ret__, 'acls'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        network_acl_name=pulumi.get(__ret__, 'network_acl_name'),
        output_file=pulumi.get(__ret__, 'output_file'),
        resource_id=pulumi.get(__ret__, 'resource_id'),
        resource_type=pulumi.get(__ret__, 'resource_type'),
        status=pulumi.get(__ret__, 'status'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))


@_utilities.lift_output_func(get_network_acls)
def get_network_acls_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                            name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                            network_acl_name: Optional[pulumi.Input[Optional[str]]] = None,
                            output_file: Optional[pulumi.Input[Optional[str]]] = None,
                            resource_id: Optional[pulumi.Input[Optional[str]]] = None,
                            resource_type: Optional[pulumi.Input[Optional[str]]] = None,
                            status: Optional[pulumi.Input[Optional[str]]] = None,
                            vpc_id: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNetworkAclsResult]:
    """
    This data source provides the Network Acls of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.122.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.vpc.get_network_acls(ids=["example_value"],
        name_regex="the_resource_name")
    pulumi.export("firstNetworkAclId", example.acls[0].id)
    ```


    :param Sequence[str] ids: A list of Network Acl ID.
    :param str name_regex: A regex string to filter results by Network Acl name.
    :param str network_acl_name: The name of the network ACL.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_id: The ID of the associated resource.
    :param str resource_type: The type of the associated resource.
    :param str status: The state of the network ACL.
    :param str vpc_id: The ID of the associated VPC.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetTransitRouteTableAggregationsResult',
    'AwaitableGetTransitRouteTableAggregationsResult',
    'get_transit_route_table_aggregations',
    'get_transit_route_table_aggregations_output',
]

@pulumi.output_type
class GetTransitRouteTableAggregationsResult:
    """
    A collection of values returned by getTransitRouteTableAggregations.
    """
    def __init__(__self__, id=None, ids=None, name_regex=None, names=None, output_file=None, status=None, transit_route_table_aggregation_cidr=None, transit_route_table_aggregations=None, transit_route_table_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if transit_route_table_aggregation_cidr and not isinstance(transit_route_table_aggregation_cidr, str):
            raise TypeError("Expected argument 'transit_route_table_aggregation_cidr' to be a str")
        pulumi.set(__self__, "transit_route_table_aggregation_cidr", transit_route_table_aggregation_cidr)
        if transit_route_table_aggregations and not isinstance(transit_route_table_aggregations, list):
            raise TypeError("Expected argument 'transit_route_table_aggregations' to be a list")
        pulumi.set(__self__, "transit_route_table_aggregations", transit_route_table_aggregations)
        if transit_route_table_id and not isinstance(transit_route_table_id, str):
            raise TypeError("Expected argument 'transit_route_table_id' to be a str")
        pulumi.set(__self__, "transit_route_table_id", transit_route_table_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of Transit Route Table Aggregation names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of the Transit Route Table Aggregation.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="transitRouteTableAggregationCidr")
    def transit_route_table_aggregation_cidr(self) -> Optional[str]:
        """
        The destination CIDR block of the aggregate route.
        """
        return pulumi.get(self, "transit_route_table_aggregation_cidr")

    @property
    @pulumi.getter(name="transitRouteTableAggregations")
    def transit_route_table_aggregations(self) -> Sequence['outputs.GetTransitRouteTableAggregationsTransitRouteTableAggregationResult']:
        """
        A list of Cen Transit Route Table Aggregations. Each element contains the following attributes:
        """
        return pulumi.get(self, "transit_route_table_aggregations")

    @property
    @pulumi.getter(name="transitRouteTableId")
    def transit_route_table_id(self) -> str:
        """
        The ID of the route table of the Enterprise Edition transit router.
        """
        return pulumi.get(self, "transit_route_table_id")


class AwaitableGetTransitRouteTableAggregationsResult(GetTransitRouteTableAggregationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTransitRouteTableAggregationsResult(
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            status=self.status,
            transit_route_table_aggregation_cidr=self.transit_route_table_aggregation_cidr,
            transit_route_table_aggregations=self.transit_route_table_aggregations,
            transit_route_table_id=self.transit_route_table_id)


def get_transit_route_table_aggregations(ids: Optional[Sequence[str]] = None,
                                         name_regex: Optional[str] = None,
                                         output_file: Optional[str] = None,
                                         status: Optional[str] = None,
                                         transit_route_table_aggregation_cidr: Optional[str] = None,
                                         transit_route_table_id: Optional[str] = None,
                                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTransitRouteTableAggregationsResult:
    """
    This data source provides the Cen Transit Route Table Aggregations of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.202.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cen.get_transit_route_table_aggregations(ids=["example_id"],
        transit_route_table_id="your_transit_route_table_id")
    pulumi.export("cenTransitRouterMulticastDomainId0", ids.transit_route_table_aggregations[0].id)
    name_regex = alicloud.cen.get_transit_route_table_aggregations(name_regex="^my-name",
        transit_route_table_id="your_transit_route_table_id")
    pulumi.export("cenTransitRouterMulticastDomainId1", name_regex.transit_route_table_aggregations[0].id)
    ```


    :param Sequence[str] ids: A list of Transit Route Table Aggregation IDs.
    :param str name_regex: A regex string to filter results by Transit Route Table Aggregation name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of Transit Route Table Aggregation. Valid Values: `AllConfigured`, `Configuring`, `ConfigFailed`, `PartialConfigured`, `Deleting`.
    :param str transit_route_table_aggregation_cidr: The destination CIDR block of the aggregate route.
    :param str transit_route_table_id: The ID of the route table of the Enterprise Edition transit router.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    __args__['transitRouteTableAggregationCidr'] = transit_route_table_aggregation_cidr
    __args__['transitRouteTableId'] = transit_route_table_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cen/getTransitRouteTableAggregations:getTransitRouteTableAggregations', __args__, opts=opts, typ=GetTransitRouteTableAggregationsResult).value

    return AwaitableGetTransitRouteTableAggregationsResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'),
        transit_route_table_aggregation_cidr=pulumi.get(__ret__, 'transit_route_table_aggregation_cidr'),
        transit_route_table_aggregations=pulumi.get(__ret__, 'transit_route_table_aggregations'),
        transit_route_table_id=pulumi.get(__ret__, 'transit_route_table_id'))


@_utilities.lift_output_func(get_transit_route_table_aggregations)
def get_transit_route_table_aggregations_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                                name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                                output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                                status: Optional[pulumi.Input[Optional[str]]] = None,
                                                transit_route_table_aggregation_cidr: Optional[pulumi.Input[Optional[str]]] = None,
                                                transit_route_table_id: Optional[pulumi.Input[str]] = None,
                                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTransitRouteTableAggregationsResult]:
    """
    This data source provides the Cen Transit Route Table Aggregations of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.202.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cen.get_transit_route_table_aggregations(ids=["example_id"],
        transit_route_table_id="your_transit_route_table_id")
    pulumi.export("cenTransitRouterMulticastDomainId0", ids.transit_route_table_aggregations[0].id)
    name_regex = alicloud.cen.get_transit_route_table_aggregations(name_regex="^my-name",
        transit_route_table_id="your_transit_route_table_id")
    pulumi.export("cenTransitRouterMulticastDomainId1", name_regex.transit_route_table_aggregations[0].id)
    ```


    :param Sequence[str] ids: A list of Transit Route Table Aggregation IDs.
    :param str name_regex: A regex string to filter results by Transit Route Table Aggregation name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of Transit Route Table Aggregation. Valid Values: `AllConfigured`, `Configuring`, `ConfigFailed`, `PartialConfigured`, `Deleting`.
    :param str transit_route_table_aggregation_cidr: The destination CIDR block of the aggregate route.
    :param str transit_route_table_id: The ID of the route table of the Enterprise Edition transit router.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WafRuleArgs', 'WafRule']

@pulumi.input_type
class WafRuleArgs:
    def __init__(__self__, *,
                 policy_id: pulumi.Input[str],
                 rule_name: pulumi.Input[str],
                 action: Optional[pulumi.Input[str]] = None,
                 cc_status: Optional[pulumi.Input[str]] = None,
                 cn_region_list: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input['WafRuleConditionArgs']]]] = None,
                 effect: Optional[pulumi.Input[str]] = None,
                 other_region_list: Optional[pulumi.Input[str]] = None,
                 rate_limit: Optional[pulumi.Input['WafRuleRateLimitArgs']] = None,
                 regular_rules: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 regular_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 remote_addrs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 scenes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 waf_group_ids: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a WafRule resource.
        :param pulumi.Input[str] policy_id: The protection policy ID.
        :param pulumi.Input[str] rule_name: The name of the protection rule. The name can be up to 64 characters in length and can contain letters, digits, and underscores (_). **NOTE:** This parameter cannot be modified when policy is of type `region_block`.
        :param pulumi.Input[str] action: Specifies the action of the rule. Valid values: `block`, `monitor`, `js`.
        :param pulumi.Input[str] cc_status: Specifies whether to enable rate limiting. Valid values: `on` and `off`. **NOTE:** This parameter is required when policy is of type `custom_acl`.
        :param pulumi.Input[str] cn_region_list: The blocked regions in the Chinese mainland, separated by commas (,).
        :param pulumi.Input[Sequence[pulumi.Input['WafRuleConditionArgs']]] conditions: Conditions that trigger the rule. See `conditions` below. **NOTE:** This parameter is required when policy is of type `custom_acl` or `whitelist`.
        :param pulumi.Input[str] effect: The effective scope of the rate limiting blacklist. If you set ccStatus to on, you must configure this parameter. Valid values: `rule` (takes effect for the current rule) and `service` (takes effect globally).
        :param pulumi.Input[str] other_region_list: Blocked regions outside the Chinese mainland, separated by commas (,).
        :param pulumi.Input['WafRuleRateLimitArgs'] rate_limit: The rules of rate limiting. If you set `cc_status` to on, you must configure this parameter. See `rate_limit` below.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regular_rules: The regular expression.e, when waf_group appears in tags, this value can be filled in, and only one list of six digits in string format can appear with regultypes.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regular_types: Regular rule type, when waf_group appears in tags, this value can be filled in, optional values:["sqli", "xss", "code_exec", "crlf", "lfileii", "rfileii", "webshell", "vvip", "other"]
        :param pulumi.Input[Sequence[pulumi.Input[str]]] remote_addrs: Filter by IP address.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scenes: The types of the protection policies.
        :param pulumi.Input[str] status: The status of the waf rule. Valid values: `on` and `off`. Default value: on.
        :param pulumi.Input[str] waf_group_ids: The id of the waf rule group. The default value is "1012". Multiple rules are separated by commas.
        """
        pulumi.set(__self__, "policy_id", policy_id)
        pulumi.set(__self__, "rule_name", rule_name)
        if action is not None:
            pulumi.set(__self__, "action", action)
        if cc_status is not None:
            pulumi.set(__self__, "cc_status", cc_status)
        if cn_region_list is not None:
            pulumi.set(__self__, "cn_region_list", cn_region_list)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if effect is not None:
            pulumi.set(__self__, "effect", effect)
        if other_region_list is not None:
            pulumi.set(__self__, "other_region_list", other_region_list)
        if rate_limit is not None:
            pulumi.set(__self__, "rate_limit", rate_limit)
        if regular_rules is not None:
            pulumi.set(__self__, "regular_rules", regular_rules)
        if regular_types is not None:
            pulumi.set(__self__, "regular_types", regular_types)
        if remote_addrs is not None:
            pulumi.set(__self__, "remote_addrs", remote_addrs)
        if scenes is not None:
            pulumi.set(__self__, "scenes", scenes)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if waf_group_ids is not None:
            pulumi.set(__self__, "waf_group_ids", waf_group_ids)

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Input[str]:
        """
        The protection policy ID.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "policy_id", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Input[str]:
        """
        The name of the protection rule. The name can be up to 64 characters in length and can contain letters, digits, and underscores (_). **NOTE:** This parameter cannot be modified when policy is of type `region_block`.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the action of the rule. Valid values: `block`, `monitor`, `js`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter(name="ccStatus")
    def cc_status(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to enable rate limiting. Valid values: `on` and `off`. **NOTE:** This parameter is required when policy is of type `custom_acl`.
        """
        return pulumi.get(self, "cc_status")

    @cc_status.setter
    def cc_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cc_status", value)

    @property
    @pulumi.getter(name="cnRegionList")
    def cn_region_list(self) -> Optional[pulumi.Input[str]]:
        """
        The blocked regions in the Chinese mainland, separated by commas (,).
        """
        return pulumi.get(self, "cn_region_list")

    @cn_region_list.setter
    def cn_region_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cn_region_list", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WafRuleConditionArgs']]]]:
        """
        Conditions that trigger the rule. See `conditions` below. **NOTE:** This parameter is required when policy is of type `custom_acl` or `whitelist`.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WafRuleConditionArgs']]]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter
    def effect(self) -> Optional[pulumi.Input[str]]:
        """
        The effective scope of the rate limiting blacklist. If you set ccStatus to on, you must configure this parameter. Valid values: `rule` (takes effect for the current rule) and `service` (takes effect globally).
        """
        return pulumi.get(self, "effect")

    @effect.setter
    def effect(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "effect", value)

    @property
    @pulumi.getter(name="otherRegionList")
    def other_region_list(self) -> Optional[pulumi.Input[str]]:
        """
        Blocked regions outside the Chinese mainland, separated by commas (,).
        """
        return pulumi.get(self, "other_region_list")

    @other_region_list.setter
    def other_region_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "other_region_list", value)

    @property
    @pulumi.getter(name="rateLimit")
    def rate_limit(self) -> Optional[pulumi.Input['WafRuleRateLimitArgs']]:
        """
        The rules of rate limiting. If you set `cc_status` to on, you must configure this parameter. See `rate_limit` below.
        """
        return pulumi.get(self, "rate_limit")

    @rate_limit.setter
    def rate_limit(self, value: Optional[pulumi.Input['WafRuleRateLimitArgs']]):
        pulumi.set(self, "rate_limit", value)

    @property
    @pulumi.getter(name="regularRules")
    def regular_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The regular expression.e, when waf_group appears in tags, this value can be filled in, and only one list of six digits in string format can appear with regultypes.
        """
        return pulumi.get(self, "regular_rules")

    @regular_rules.setter
    def regular_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "regular_rules", value)

    @property
    @pulumi.getter(name="regularTypes")
    def regular_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Regular rule type, when waf_group appears in tags, this value can be filled in, optional values:["sqli", "xss", "code_exec", "crlf", "lfileii", "rfileii", "webshell", "vvip", "other"]
        """
        return pulumi.get(self, "regular_types")

    @regular_types.setter
    def regular_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "regular_types", value)

    @property
    @pulumi.getter(name="remoteAddrs")
    def remote_addrs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Filter by IP address.
        """
        return pulumi.get(self, "remote_addrs")

    @remote_addrs.setter
    def remote_addrs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "remote_addrs", value)

    @property
    @pulumi.getter
    def scenes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The types of the protection policies.
        """
        return pulumi.get(self, "scenes")

    @scenes.setter
    def scenes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "scenes", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the waf rule. Valid values: `on` and `off`. Default value: on.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="wafGroupIds")
    def waf_group_ids(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the waf rule group. The default value is "1012". Multiple rules are separated by commas.
        """
        return pulumi.get(self, "waf_group_ids")

    @waf_group_ids.setter
    def waf_group_ids(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "waf_group_ids", value)


@pulumi.input_type
class _WafRuleState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[str]] = None,
                 cc_status: Optional[pulumi.Input[str]] = None,
                 cn_region_list: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input['WafRuleConditionArgs']]]] = None,
                 defense_scene: Optional[pulumi.Input[str]] = None,
                 effect: Optional[pulumi.Input[str]] = None,
                 gmt_modified: Optional[pulumi.Input[str]] = None,
                 other_region_list: Optional[pulumi.Input[str]] = None,
                 policy_id: Optional[pulumi.Input[str]] = None,
                 rate_limit: Optional[pulumi.Input['WafRuleRateLimitArgs']] = None,
                 regular_rules: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 regular_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 remote_addrs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 scenes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 waf_group_ids: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering WafRule resources.
        :param pulumi.Input[str] action: Specifies the action of the rule. Valid values: `block`, `monitor`, `js`.
        :param pulumi.Input[str] cc_status: Specifies whether to enable rate limiting. Valid values: `on` and `off`. **NOTE:** This parameter is required when policy is of type `custom_acl`.
        :param pulumi.Input[str] cn_region_list: The blocked regions in the Chinese mainland, separated by commas (,).
        :param pulumi.Input[Sequence[pulumi.Input['WafRuleConditionArgs']]] conditions: Conditions that trigger the rule. See `conditions` below. **NOTE:** This parameter is required when policy is of type `custom_acl` or `whitelist`.
        :param pulumi.Input[str] defense_scene: The type of protection policy. The following scenarios are supported:-waf_group:Web basic protection-custom_acl: Custom protection policy-whitelist: whitelist
        :param pulumi.Input[str] effect: The effective scope of the rate limiting blacklist. If you set ccStatus to on, you must configure this parameter. Valid values: `rule` (takes effect for the current rule) and `service` (takes effect globally).
        :param pulumi.Input[str] gmt_modified: Revised the time. The date format is based on ISO8601 notation and uses UTC +0 time in the format of yyyy-MM-ddTHH:mm:ssZ.
        :param pulumi.Input[str] other_region_list: Blocked regions outside the Chinese mainland, separated by commas (,).
        :param pulumi.Input[str] policy_id: The protection policy ID.
        :param pulumi.Input['WafRuleRateLimitArgs'] rate_limit: The rules of rate limiting. If you set `cc_status` to on, you must configure this parameter. See `rate_limit` below.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regular_rules: The regular expression.e, when waf_group appears in tags, this value can be filled in, and only one list of six digits in string format can appear with regultypes.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regular_types: Regular rule type, when waf_group appears in tags, this value can be filled in, optional values:["sqli", "xss", "code_exec", "crlf", "lfileii", "rfileii", "webshell", "vvip", "other"]
        :param pulumi.Input[Sequence[pulumi.Input[str]]] remote_addrs: Filter by IP address.
        :param pulumi.Input[str] rule_name: The name of the protection rule. The name can be up to 64 characters in length and can contain letters, digits, and underscores (_). **NOTE:** This parameter cannot be modified when policy is of type `region_block`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scenes: The types of the protection policies.
        :param pulumi.Input[str] status: The status of the waf rule. Valid values: `on` and `off`. Default value: on.
        :param pulumi.Input[str] waf_group_ids: The id of the waf rule group. The default value is "1012". Multiple rules are separated by commas.
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if cc_status is not None:
            pulumi.set(__self__, "cc_status", cc_status)
        if cn_region_list is not None:
            pulumi.set(__self__, "cn_region_list", cn_region_list)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if defense_scene is not None:
            pulumi.set(__self__, "defense_scene", defense_scene)
        if effect is not None:
            pulumi.set(__self__, "effect", effect)
        if gmt_modified is not None:
            pulumi.set(__self__, "gmt_modified", gmt_modified)
        if other_region_list is not None:
            pulumi.set(__self__, "other_region_list", other_region_list)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)
        if rate_limit is not None:
            pulumi.set(__self__, "rate_limit", rate_limit)
        if regular_rules is not None:
            pulumi.set(__self__, "regular_rules", regular_rules)
        if regular_types is not None:
            pulumi.set(__self__, "regular_types", regular_types)
        if remote_addrs is not None:
            pulumi.set(__self__, "remote_addrs", remote_addrs)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if scenes is not None:
            pulumi.set(__self__, "scenes", scenes)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if waf_group_ids is not None:
            pulumi.set(__self__, "waf_group_ids", waf_group_ids)

    @property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the action of the rule. Valid values: `block`, `monitor`, `js`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter(name="ccStatus")
    def cc_status(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to enable rate limiting. Valid values: `on` and `off`. **NOTE:** This parameter is required when policy is of type `custom_acl`.
        """
        return pulumi.get(self, "cc_status")

    @cc_status.setter
    def cc_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cc_status", value)

    @property
    @pulumi.getter(name="cnRegionList")
    def cn_region_list(self) -> Optional[pulumi.Input[str]]:
        """
        The blocked regions in the Chinese mainland, separated by commas (,).
        """
        return pulumi.get(self, "cn_region_list")

    @cn_region_list.setter
    def cn_region_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cn_region_list", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WafRuleConditionArgs']]]]:
        """
        Conditions that trigger the rule. See `conditions` below. **NOTE:** This parameter is required when policy is of type `custom_acl` or `whitelist`.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WafRuleConditionArgs']]]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter(name="defenseScene")
    def defense_scene(self) -> Optional[pulumi.Input[str]]:
        """
        The type of protection policy. The following scenarios are supported:-waf_group:Web basic protection-custom_acl: Custom protection policy-whitelist: whitelist
        """
        return pulumi.get(self, "defense_scene")

    @defense_scene.setter
    def defense_scene(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defense_scene", value)

    @property
    @pulumi.getter
    def effect(self) -> Optional[pulumi.Input[str]]:
        """
        The effective scope of the rate limiting blacklist. If you set ccStatus to on, you must configure this parameter. Valid values: `rule` (takes effect for the current rule) and `service` (takes effect globally).
        """
        return pulumi.get(self, "effect")

    @effect.setter
    def effect(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "effect", value)

    @property
    @pulumi.getter(name="gmtModified")
    def gmt_modified(self) -> Optional[pulumi.Input[str]]:
        """
        Revised the time. The date format is based on ISO8601 notation and uses UTC +0 time in the format of yyyy-MM-ddTHH:mm:ssZ.
        """
        return pulumi.get(self, "gmt_modified")

    @gmt_modified.setter
    def gmt_modified(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gmt_modified", value)

    @property
    @pulumi.getter(name="otherRegionList")
    def other_region_list(self) -> Optional[pulumi.Input[str]]:
        """
        Blocked regions outside the Chinese mainland, separated by commas (,).
        """
        return pulumi.get(self, "other_region_list")

    @other_region_list.setter
    def other_region_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "other_region_list", value)

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[str]]:
        """
        The protection policy ID.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_id", value)

    @property
    @pulumi.getter(name="rateLimit")
    def rate_limit(self) -> Optional[pulumi.Input['WafRuleRateLimitArgs']]:
        """
        The rules of rate limiting. If you set `cc_status` to on, you must configure this parameter. See `rate_limit` below.
        """
        return pulumi.get(self, "rate_limit")

    @rate_limit.setter
    def rate_limit(self, value: Optional[pulumi.Input['WafRuleRateLimitArgs']]):
        pulumi.set(self, "rate_limit", value)

    @property
    @pulumi.getter(name="regularRules")
    def regular_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The regular expression.e, when waf_group appears in tags, this value can be filled in, and only one list of six digits in string format can appear with regultypes.
        """
        return pulumi.get(self, "regular_rules")

    @regular_rules.setter
    def regular_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "regular_rules", value)

    @property
    @pulumi.getter(name="regularTypes")
    def regular_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Regular rule type, when waf_group appears in tags, this value can be filled in, optional values:["sqli", "xss", "code_exec", "crlf", "lfileii", "rfileii", "webshell", "vvip", "other"]
        """
        return pulumi.get(self, "regular_types")

    @regular_types.setter
    def regular_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "regular_types", value)

    @property
    @pulumi.getter(name="remoteAddrs")
    def remote_addrs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Filter by IP address.
        """
        return pulumi.get(self, "remote_addrs")

    @remote_addrs.setter
    def remote_addrs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "remote_addrs", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the protection rule. The name can be up to 64 characters in length and can contain letters, digits, and underscores (_). **NOTE:** This parameter cannot be modified when policy is of type `region_block`.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter
    def scenes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The types of the protection policies.
        """
        return pulumi.get(self, "scenes")

    @scenes.setter
    def scenes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "scenes", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the waf rule. Valid values: `on` and `off`. Default value: on.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="wafGroupIds")
    def waf_group_ids(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the waf rule group. The default value is "1012". Multiple rules are separated by commas.
        """
        return pulumi.get(self, "waf_group_ids")

    @waf_group_ids.setter
    def waf_group_ids(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "waf_group_ids", value)


class WafRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[str]] = None,
                 cc_status: Optional[pulumi.Input[str]] = None,
                 cn_region_list: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['WafRuleConditionArgs']]]]] = None,
                 effect: Optional[pulumi.Input[str]] = None,
                 other_region_list: Optional[pulumi.Input[str]] = None,
                 policy_id: Optional[pulumi.Input[str]] = None,
                 rate_limit: Optional[pulumi.Input[pulumi.InputType['WafRuleRateLimitArgs']]] = None,
                 regular_rules: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 regular_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 remote_addrs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 scenes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 waf_group_ids: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Dcdn Waf Rule resource.

        For information about Dcdn Waf Rule and how to use it, see [What is Waf Rule](https://www.alibabacloud.com/help/en/dynamic-route-for-cdn/latest/configure-protection-rules).

        > **NOTE:** Available since v1.201.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        example_waf_policy = alicloud.dcdn.WafPolicy("exampleWafPolicy",
            defense_scene="waf_group",
            policy_name=name,
            policy_type="custom",
            status="on")
        example_waf_rule = alicloud.dcdn.WafRule("exampleWafRule",
            policy_id=example_waf_policy.id,
            rule_name=name,
            conditions=[
                alicloud.dcdn.WafRuleConditionArgs(
                    key="URI",
                    op_value="ne",
                    values="/login.php",
                ),
                alicloud.dcdn.WafRuleConditionArgs(
                    key="Header",
                    sub_key="a",
                    op_value="eq",
                    values="b",
                ),
            ],
            status="on",
            cc_status="on",
            action="monitor",
            effect="rule",
            rate_limit=alicloud.dcdn.WafRuleRateLimitArgs(
                target="IP",
                interval=5,
                threshold=5,
                ttl=1800,
                status=alicloud.dcdn.WafRuleRateLimitStatusArgs(
                    code="200",
                    ratio=60,
                ),
            ))
        ```

        ## Import

        Dcdn Waf Rule can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:dcdn/wafRule:WafRule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action: Specifies the action of the rule. Valid values: `block`, `monitor`, `js`.
        :param pulumi.Input[str] cc_status: Specifies whether to enable rate limiting. Valid values: `on` and `off`. **NOTE:** This parameter is required when policy is of type `custom_acl`.
        :param pulumi.Input[str] cn_region_list: The blocked regions in the Chinese mainland, separated by commas (,).
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['WafRuleConditionArgs']]]] conditions: Conditions that trigger the rule. See `conditions` below. **NOTE:** This parameter is required when policy is of type `custom_acl` or `whitelist`.
        :param pulumi.Input[str] effect: The effective scope of the rate limiting blacklist. If you set ccStatus to on, you must configure this parameter. Valid values: `rule` (takes effect for the current rule) and `service` (takes effect globally).
        :param pulumi.Input[str] other_region_list: Blocked regions outside the Chinese mainland, separated by commas (,).
        :param pulumi.Input[str] policy_id: The protection policy ID.
        :param pulumi.Input[pulumi.InputType['WafRuleRateLimitArgs']] rate_limit: The rules of rate limiting. If you set `cc_status` to on, you must configure this parameter. See `rate_limit` below.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regular_rules: The regular expression.e, when waf_group appears in tags, this value can be filled in, and only one list of six digits in string format can appear with regultypes.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regular_types: Regular rule type, when waf_group appears in tags, this value can be filled in, optional values:["sqli", "xss", "code_exec", "crlf", "lfileii", "rfileii", "webshell", "vvip", "other"]
        :param pulumi.Input[Sequence[pulumi.Input[str]]] remote_addrs: Filter by IP address.
        :param pulumi.Input[str] rule_name: The name of the protection rule. The name can be up to 64 characters in length and can contain letters, digits, and underscores (_). **NOTE:** This parameter cannot be modified when policy is of type `region_block`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scenes: The types of the protection policies.
        :param pulumi.Input[str] status: The status of the waf rule. Valid values: `on` and `off`. Default value: on.
        :param pulumi.Input[str] waf_group_ids: The id of the waf rule group. The default value is "1012". Multiple rules are separated by commas.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WafRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Dcdn Waf Rule resource.

        For information about Dcdn Waf Rule and how to use it, see [What is Waf Rule](https://www.alibabacloud.com/help/en/dynamic-route-for-cdn/latest/configure-protection-rules).

        > **NOTE:** Available since v1.201.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        example_waf_policy = alicloud.dcdn.WafPolicy("exampleWafPolicy",
            defense_scene="waf_group",
            policy_name=name,
            policy_type="custom",
            status="on")
        example_waf_rule = alicloud.dcdn.WafRule("exampleWafRule",
            policy_id=example_waf_policy.id,
            rule_name=name,
            conditions=[
                alicloud.dcdn.WafRuleConditionArgs(
                    key="URI",
                    op_value="ne",
                    values="/login.php",
                ),
                alicloud.dcdn.WafRuleConditionArgs(
                    key="Header",
                    sub_key="a",
                    op_value="eq",
                    values="b",
                ),
            ],
            status="on",
            cc_status="on",
            action="monitor",
            effect="rule",
            rate_limit=alicloud.dcdn.WafRuleRateLimitArgs(
                target="IP",
                interval=5,
                threshold=5,
                ttl=1800,
                status=alicloud.dcdn.WafRuleRateLimitStatusArgs(
                    code="200",
                    ratio=60,
                ),
            ))
        ```

        ## Import

        Dcdn Waf Rule can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:dcdn/wafRule:WafRule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param WafRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WafRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[str]] = None,
                 cc_status: Optional[pulumi.Input[str]] = None,
                 cn_region_list: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['WafRuleConditionArgs']]]]] = None,
                 effect: Optional[pulumi.Input[str]] = None,
                 other_region_list: Optional[pulumi.Input[str]] = None,
                 policy_id: Optional[pulumi.Input[str]] = None,
                 rate_limit: Optional[pulumi.Input[pulumi.InputType['WafRuleRateLimitArgs']]] = None,
                 regular_rules: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 regular_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 remote_addrs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 scenes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 waf_group_ids: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WafRuleArgs.__new__(WafRuleArgs)

            __props__.__dict__["action"] = action
            __props__.__dict__["cc_status"] = cc_status
            __props__.__dict__["cn_region_list"] = cn_region_list
            __props__.__dict__["conditions"] = conditions
            __props__.__dict__["effect"] = effect
            __props__.__dict__["other_region_list"] = other_region_list
            if policy_id is None and not opts.urn:
                raise TypeError("Missing required property 'policy_id'")
            __props__.__dict__["policy_id"] = policy_id
            __props__.__dict__["rate_limit"] = rate_limit
            __props__.__dict__["regular_rules"] = regular_rules
            __props__.__dict__["regular_types"] = regular_types
            __props__.__dict__["remote_addrs"] = remote_addrs
            if rule_name is None and not opts.urn:
                raise TypeError("Missing required property 'rule_name'")
            __props__.__dict__["rule_name"] = rule_name
            __props__.__dict__["scenes"] = scenes
            __props__.__dict__["status"] = status
            __props__.__dict__["waf_group_ids"] = waf_group_ids
            __props__.__dict__["defense_scene"] = None
            __props__.__dict__["gmt_modified"] = None
        super(WafRule, __self__).__init__(
            'alicloud:dcdn/wafRule:WafRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[str]] = None,
            cc_status: Optional[pulumi.Input[str]] = None,
            cn_region_list: Optional[pulumi.Input[str]] = None,
            conditions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['WafRuleConditionArgs']]]]] = None,
            defense_scene: Optional[pulumi.Input[str]] = None,
            effect: Optional[pulumi.Input[str]] = None,
            gmt_modified: Optional[pulumi.Input[str]] = None,
            other_region_list: Optional[pulumi.Input[str]] = None,
            policy_id: Optional[pulumi.Input[str]] = None,
            rate_limit: Optional[pulumi.Input[pulumi.InputType['WafRuleRateLimitArgs']]] = None,
            regular_rules: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            regular_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            remote_addrs: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            rule_name: Optional[pulumi.Input[str]] = None,
            scenes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            status: Optional[pulumi.Input[str]] = None,
            waf_group_ids: Optional[pulumi.Input[str]] = None) -> 'WafRule':
        """
        Get an existing WafRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action: Specifies the action of the rule. Valid values: `block`, `monitor`, `js`.
        :param pulumi.Input[str] cc_status: Specifies whether to enable rate limiting. Valid values: `on` and `off`. **NOTE:** This parameter is required when policy is of type `custom_acl`.
        :param pulumi.Input[str] cn_region_list: The blocked regions in the Chinese mainland, separated by commas (,).
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['WafRuleConditionArgs']]]] conditions: Conditions that trigger the rule. See `conditions` below. **NOTE:** This parameter is required when policy is of type `custom_acl` or `whitelist`.
        :param pulumi.Input[str] defense_scene: The type of protection policy. The following scenarios are supported:-waf_group:Web basic protection-custom_acl: Custom protection policy-whitelist: whitelist
        :param pulumi.Input[str] effect: The effective scope of the rate limiting blacklist. If you set ccStatus to on, you must configure this parameter. Valid values: `rule` (takes effect for the current rule) and `service` (takes effect globally).
        :param pulumi.Input[str] gmt_modified: Revised the time. The date format is based on ISO8601 notation and uses UTC +0 time in the format of yyyy-MM-ddTHH:mm:ssZ.
        :param pulumi.Input[str] other_region_list: Blocked regions outside the Chinese mainland, separated by commas (,).
        :param pulumi.Input[str] policy_id: The protection policy ID.
        :param pulumi.Input[pulumi.InputType['WafRuleRateLimitArgs']] rate_limit: The rules of rate limiting. If you set `cc_status` to on, you must configure this parameter. See `rate_limit` below.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regular_rules: The regular expression.e, when waf_group appears in tags, this value can be filled in, and only one list of six digits in string format can appear with regultypes.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regular_types: Regular rule type, when waf_group appears in tags, this value can be filled in, optional values:["sqli", "xss", "code_exec", "crlf", "lfileii", "rfileii", "webshell", "vvip", "other"]
        :param pulumi.Input[Sequence[pulumi.Input[str]]] remote_addrs: Filter by IP address.
        :param pulumi.Input[str] rule_name: The name of the protection rule. The name can be up to 64 characters in length and can contain letters, digits, and underscores (_). **NOTE:** This parameter cannot be modified when policy is of type `region_block`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scenes: The types of the protection policies.
        :param pulumi.Input[str] status: The status of the waf rule. Valid values: `on` and `off`. Default value: on.
        :param pulumi.Input[str] waf_group_ids: The id of the waf rule group. The default value is "1012". Multiple rules are separated by commas.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WafRuleState.__new__(_WafRuleState)

        __props__.__dict__["action"] = action
        __props__.__dict__["cc_status"] = cc_status
        __props__.__dict__["cn_region_list"] = cn_region_list
        __props__.__dict__["conditions"] = conditions
        __props__.__dict__["defense_scene"] = defense_scene
        __props__.__dict__["effect"] = effect
        __props__.__dict__["gmt_modified"] = gmt_modified
        __props__.__dict__["other_region_list"] = other_region_list
        __props__.__dict__["policy_id"] = policy_id
        __props__.__dict__["rate_limit"] = rate_limit
        __props__.__dict__["regular_rules"] = regular_rules
        __props__.__dict__["regular_types"] = regular_types
        __props__.__dict__["remote_addrs"] = remote_addrs
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["scenes"] = scenes
        __props__.__dict__["status"] = status
        __props__.__dict__["waf_group_ids"] = waf_group_ids
        return WafRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the action of the rule. Valid values: `block`, `monitor`, `js`.
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter(name="ccStatus")
    def cc_status(self) -> pulumi.Output[str]:
        """
        Specifies whether to enable rate limiting. Valid values: `on` and `off`. **NOTE:** This parameter is required when policy is of type `custom_acl`.
        """
        return pulumi.get(self, "cc_status")

    @property
    @pulumi.getter(name="cnRegionList")
    def cn_region_list(self) -> pulumi.Output[Optional[str]]:
        """
        The blocked regions in the Chinese mainland, separated by commas (,).
        """
        return pulumi.get(self, "cn_region_list")

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Output[Optional[Sequence['outputs.WafRuleCondition']]]:
        """
        Conditions that trigger the rule. See `conditions` below. **NOTE:** This parameter is required when policy is of type `custom_acl` or `whitelist`.
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter(name="defenseScene")
    def defense_scene(self) -> pulumi.Output[str]:
        """
        The type of protection policy. The following scenarios are supported:-waf_group:Web basic protection-custom_acl: Custom protection policy-whitelist: whitelist
        """
        return pulumi.get(self, "defense_scene")

    @property
    @pulumi.getter
    def effect(self) -> pulumi.Output[Optional[str]]:
        """
        The effective scope of the rate limiting blacklist. If you set ccStatus to on, you must configure this parameter. Valid values: `rule` (takes effect for the current rule) and `service` (takes effect globally).
        """
        return pulumi.get(self, "effect")

    @property
    @pulumi.getter(name="gmtModified")
    def gmt_modified(self) -> pulumi.Output[str]:
        """
        Revised the time. The date format is based on ISO8601 notation and uses UTC +0 time in the format of yyyy-MM-ddTHH:mm:ssZ.
        """
        return pulumi.get(self, "gmt_modified")

    @property
    @pulumi.getter(name="otherRegionList")
    def other_region_list(self) -> pulumi.Output[Optional[str]]:
        """
        Blocked regions outside the Chinese mainland, separated by commas (,).
        """
        return pulumi.get(self, "other_region_list")

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Output[str]:
        """
        The protection policy ID.
        """
        return pulumi.get(self, "policy_id")

    @property
    @pulumi.getter(name="rateLimit")
    def rate_limit(self) -> pulumi.Output[Optional['outputs.WafRuleRateLimit']]:
        """
        The rules of rate limiting. If you set `cc_status` to on, you must configure this parameter. See `rate_limit` below.
        """
        return pulumi.get(self, "rate_limit")

    @property
    @pulumi.getter(name="regularRules")
    def regular_rules(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The regular expression.e, when waf_group appears in tags, this value can be filled in, and only one list of six digits in string format can appear with regultypes.
        """
        return pulumi.get(self, "regular_rules")

    @property
    @pulumi.getter(name="regularTypes")
    def regular_types(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Regular rule type, when waf_group appears in tags, this value can be filled in, optional values:["sqli", "xss", "code_exec", "crlf", "lfileii", "rfileii", "webshell", "vvip", "other"]
        """
        return pulumi.get(self, "regular_types")

    @property
    @pulumi.getter(name="remoteAddrs")
    def remote_addrs(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Filter by IP address.
        """
        return pulumi.get(self, "remote_addrs")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[str]:
        """
        The name of the protection rule. The name can be up to 64 characters in length and can contain letters, digits, and underscores (_). **NOTE:** This parameter cannot be modified when policy is of type `region_block`.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter
    def scenes(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The types of the protection policies.
        """
        return pulumi.get(self, "scenes")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the waf rule. Valid values: `on` and `off`. Default value: on.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="wafGroupIds")
    def waf_group_ids(self) -> pulumi.Output[Optional[str]]:
        """
        The id of the waf rule group. The default value is "1012". Multiple rules are separated by commas.
        """
        return pulumi.get(self, "waf_group_ids")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetAclsResult',
    'AwaitableGetAclsResult',
    'get_acls',
    'get_acls_output',
]

@pulumi.output_type
class GetAclsResult:
    """
    A collection of values returned by getAcls.
    """
    def __init__(__self__, acl_ids=None, acl_name=None, acls=None, enable_details=None, id=None, ids=None, name_regex=None, names=None, output_file=None, resource_group_id=None, status=None):
        if acl_ids and not isinstance(acl_ids, list):
            raise TypeError("Expected argument 'acl_ids' to be a list")
        pulumi.set(__self__, "acl_ids", acl_ids)
        if acl_name and not isinstance(acl_name, str):
            raise TypeError("Expected argument 'acl_name' to be a str")
        pulumi.set(__self__, "acl_name", acl_name)
        if acls and not isinstance(acls, list):
            raise TypeError("Expected argument 'acls' to be a list")
        pulumi.set(__self__, "acls", acls)
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="aclIds")
    def acl_ids(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "acl_ids")

    @property
    @pulumi.getter(name="aclName")
    def acl_name(self) -> Optional[str]:
        return pulumi.get(self, "acl_name")

    @property
    @pulumi.getter
    def acls(self) -> Sequence['outputs.GetAclsAclResult']:
        return pulumi.get(self, "acls")

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[str]:
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


class AwaitableGetAclsResult(GetAclsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAclsResult(
            acl_ids=self.acl_ids,
            acl_name=self.acl_name,
            acls=self.acls,
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            resource_group_id=self.resource_group_id,
            status=self.status)


def get_acls(acl_ids: Optional[Sequence[str]] = None,
             acl_name: Optional[str] = None,
             enable_details: Optional[bool] = None,
             ids: Optional[Sequence[str]] = None,
             name_regex: Optional[str] = None,
             output_file: Optional[str] = None,
             resource_group_id: Optional[str] = None,
             status: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAclsResult:
    """
    This data source provides the Application Load Balancer (ALB) Acls of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.133.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.alb.get_acls()
    pulumi.export("albAclId1", ids.acls[0].id)
    name_regex = alicloud.alb.get_acls(name_regex="^my-Acl")
    pulumi.export("albAclId2", name_regex.acls[0].id)
    ```


    :param Sequence[str] acl_ids: The acl ids.
    :param str acl_name: The ACL Name.
    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Acl IDs.
    :param str name_regex: A regex string to filter results by Acl name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: Resource Group to Which the Number.
    :param str status: The state of the ACL. Valid values:`Provisioning` , `Available` and `Configuring`. `Provisioning`: The ACL is being created. `Available`: The ACL is available. `Configuring`: The ACL is being configured.
    """
    __args__ = dict()
    __args__['aclIds'] = acl_ids
    __args__['aclName'] = acl_name
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:alb/getAcls:getAcls', __args__, opts=opts, typ=GetAclsResult).value

    return AwaitableGetAclsResult(
        acl_ids=pulumi.get(__ret__, 'acl_ids'),
        acl_name=pulumi.get(__ret__, 'acl_name'),
        acls=pulumi.get(__ret__, 'acls'),
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        status=pulumi.get(__ret__, 'status'))


@_utilities.lift_output_func(get_acls)
def get_acls_output(acl_ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                    acl_name: Optional[pulumi.Input[Optional[str]]] = None,
                    enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                    ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                    name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                    output_file: Optional[pulumi.Input[Optional[str]]] = None,
                    resource_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                    status: Optional[pulumi.Input[Optional[str]]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAclsResult]:
    """
    This data source provides the Application Load Balancer (ALB) Acls of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.133.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.alb.get_acls()
    pulumi.export("albAclId1", ids.acls[0].id)
    name_regex = alicloud.alb.get_acls(name_regex="^my-Acl")
    pulumi.export("albAclId2", name_regex.acls[0].id)
    ```


    :param Sequence[str] acl_ids: The acl ids.
    :param str acl_name: The ACL Name.
    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Acl IDs.
    :param str name_regex: A regex string to filter results by Acl name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: Resource Group to Which the Number.
    :param str status: The state of the ACL. Valid values:`Provisioning` , `Available` and `Configuring`. `Provisioning`: The ACL is being created. `Available`: The ACL is available. `Configuring`: The ACL is being configured.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['CertificateArgs', 'Certificate']

@pulumi.input_type
class CertificateArgs:
    def __init__(__self__, *,
                 cert: pulumi.Input[str],
                 key: pulumi.Input[str],
                 certificate_name: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Certificate resource.
        :param pulumi.Input[str] cert: Cert of the Certificate in which the Certificate will add.
        :param pulumi.Input[str] key: Key of the Certificate in which the Certificate will add.
        :param pulumi.Input[str] name: Name of the Certificate. This name without suffix can have a string of 1 to 63 characters, must contain only alphanumeric characters or "-", and must not begin or end with "-", and "-" must not in the 3th and 4th character positions at the same time. Suffix `.sh` and `.tel` are not supported.
        """
        pulumi.set(__self__, "cert", cert)
        pulumi.set(__self__, "key", key)
        if certificate_name is not None:
            pulumi.set(__self__, "certificate_name", certificate_name)
        if lang is not None:
            pulumi.set(__self__, "lang", lang)
        if name is not None:
            warnings.warn("""attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""name is deprecated: attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""")
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def cert(self) -> pulumi.Input[str]:
        """
        Cert of the Certificate in which the Certificate will add.
        """
        return pulumi.get(self, "cert")

    @cert.setter
    def cert(self, value: pulumi.Input[str]):
        pulumi.set(self, "cert", value)

    @property
    @pulumi.getter
    def key(self) -> pulumi.Input[str]:
        """
        Key of the Certificate in which the Certificate will add.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter(name="certificateName")
    def certificate_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "certificate_name")

    @certificate_name.setter
    def certificate_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "certificate_name", value)

    @property
    @pulumi.getter
    def lang(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "lang")

    @lang.setter
    def lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lang", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Certificate. This name without suffix can have a string of 1 to 63 characters, must contain only alphanumeric characters or "-", and must not begin or end with "-", and "-" must not in the 3th and 4th character positions at the same time. Suffix `.sh` and `.tel` are not supported.
        """
        warnings.warn("""attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""", DeprecationWarning)
        pulumi.log.warn("""name is deprecated: attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""")

        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _CertificateState:
    def __init__(__self__, *,
                 cert: Optional[pulumi.Input[str]] = None,
                 certificate_name: Optional[pulumi.Input[str]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Certificate resources.
        :param pulumi.Input[str] cert: Cert of the Certificate in which the Certificate will add.
        :param pulumi.Input[str] key: Key of the Certificate in which the Certificate will add.
        :param pulumi.Input[str] name: Name of the Certificate. This name without suffix can have a string of 1 to 63 characters, must contain only alphanumeric characters or "-", and must not begin or end with "-", and "-" must not in the 3th and 4th character positions at the same time. Suffix `.sh` and `.tel` are not supported.
        """
        if cert is not None:
            pulumi.set(__self__, "cert", cert)
        if certificate_name is not None:
            pulumi.set(__self__, "certificate_name", certificate_name)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if lang is not None:
            pulumi.set(__self__, "lang", lang)
        if name is not None:
            warnings.warn("""attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""name is deprecated: attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""")
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def cert(self) -> Optional[pulumi.Input[str]]:
        """
        Cert of the Certificate in which the Certificate will add.
        """
        return pulumi.get(self, "cert")

    @cert.setter
    def cert(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cert", value)

    @property
    @pulumi.getter(name="certificateName")
    def certificate_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "certificate_name")

    @certificate_name.setter
    def certificate_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "certificate_name", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        Key of the Certificate in which the Certificate will add.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def lang(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "lang")

    @lang.setter
    def lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lang", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Certificate. This name without suffix can have a string of 1 to 63 characters, must contain only alphanumeric characters or "-", and must not begin or end with "-", and "-" must not in the 3th and 4th character positions at the same time. Suffix `.sh` and `.tel` are not supported.
        """
        warnings.warn("""attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""", DeprecationWarning)
        pulumi.log.warn("""name is deprecated: attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""")

        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


warnings.warn("""This resource has been deprecated in favour of ServiceCertificate""", DeprecationWarning)


class Certificate(pulumi.CustomResource):
    warnings.warn("""This resource has been deprecated in favour of ServiceCertificate""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cert: Optional[pulumi.Input[str]] = None,
                 certificate_name: Optional[pulumi.Input[str]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        > **DEPRECATED:**  This datasource has been deprecated from version `1.129.0`. Please use new datasource alicloud_ssl_certificates_service_certificate.

        Provides a CAS Certificate resource.

        > **NOTE:** The Certificate name which you want to add must be already registered and had not added by another account. Every Certificate name can only exist in a unique group.

        > **NOTE:** The Cas Certificate region only support cn-hangzhou, ap-south-1, me-east-1, eu-central-1, ap-northeast-1, ap-southeast-2.

        > **NOTE:** Available in 1.35.0+ .

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Add a new Certificate.
        cert = alicloud.cas.Certificate("cert",
            cert=(lambda path: open(path).read())(f"{path['module']}/test.crt"),
            key=(lambda path: open(path).read())(f"{path['module']}/test.key"))
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cert: Cert of the Certificate in which the Certificate will add.
        :param pulumi.Input[str] key: Key of the Certificate in which the Certificate will add.
        :param pulumi.Input[str] name: Name of the Certificate. This name without suffix can have a string of 1 to 63 characters, must contain only alphanumeric characters or "-", and must not begin or end with "-", and "-" must not in the 3th and 4th character positions at the same time. Suffix `.sh` and `.tel` are not supported.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CertificateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        > **DEPRECATED:**  This datasource has been deprecated from version `1.129.0`. Please use new datasource alicloud_ssl_certificates_service_certificate.

        Provides a CAS Certificate resource.

        > **NOTE:** The Certificate name which you want to add must be already registered and had not added by another account. Every Certificate name can only exist in a unique group.

        > **NOTE:** The Cas Certificate region only support cn-hangzhou, ap-south-1, me-east-1, eu-central-1, ap-northeast-1, ap-southeast-2.

        > **NOTE:** Available in 1.35.0+ .

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Add a new Certificate.
        cert = alicloud.cas.Certificate("cert",
            cert=(lambda path: open(path).read())(f"{path['module']}/test.crt"),
            key=(lambda path: open(path).read())(f"{path['module']}/test.key"))
        ```

        :param str resource_name: The name of the resource.
        :param CertificateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CertificateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cert: Optional[pulumi.Input[str]] = None,
                 certificate_name: Optional[pulumi.Input[str]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        pulumi.log.warn("""Certificate is deprecated: This resource has been deprecated in favour of ServiceCertificate""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CertificateArgs.__new__(CertificateArgs)

            if cert is None and not opts.urn:
                raise TypeError("Missing required property 'cert'")
            __props__.__dict__["cert"] = cert
            __props__.__dict__["certificate_name"] = certificate_name
            if key is None and not opts.urn:
                raise TypeError("Missing required property 'key'")
            __props__.__dict__["key"] = key
            __props__.__dict__["lang"] = lang
            if name is not None and not opts.urn:
                warnings.warn("""attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""", DeprecationWarning)
                pulumi.log.warn("""name is deprecated: attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""")
            __props__.__dict__["name"] = name
        super(Certificate, __self__).__init__(
            'alicloud:cas/certificate:Certificate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cert: Optional[pulumi.Input[str]] = None,
            certificate_name: Optional[pulumi.Input[str]] = None,
            key: Optional[pulumi.Input[str]] = None,
            lang: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'Certificate':
        """
        Get an existing Certificate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cert: Cert of the Certificate in which the Certificate will add.
        :param pulumi.Input[str] key: Key of the Certificate in which the Certificate will add.
        :param pulumi.Input[str] name: Name of the Certificate. This name without suffix can have a string of 1 to 63 characters, must contain only alphanumeric characters or "-", and must not begin or end with "-", and "-" must not in the 3th and 4th character positions at the same time. Suffix `.sh` and `.tel` are not supported.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CertificateState.__new__(_CertificateState)

        __props__.__dict__["cert"] = cert
        __props__.__dict__["certificate_name"] = certificate_name
        __props__.__dict__["key"] = key
        __props__.__dict__["lang"] = lang
        __props__.__dict__["name"] = name
        return Certificate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def cert(self) -> pulumi.Output[str]:
        """
        Cert of the Certificate in which the Certificate will add.
        """
        return pulumi.get(self, "cert")

    @property
    @pulumi.getter(name="certificateName")
    def certificate_name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "certificate_name")

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[str]:
        """
        Key of the Certificate in which the Certificate will add.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def lang(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "lang")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the Certificate. This name without suffix can have a string of 1 to 63 characters, must contain only alphanumeric characters or "-", and must not begin or end with "-", and "-" must not in the 3th and 4th character positions at the same time. Suffix `.sh` and `.tel` are not supported.
        """
        warnings.warn("""attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""", DeprecationWarning)
        pulumi.log.warn("""name is deprecated: attribute 'name' has been deprecated from provider version 1.129.0 and it will be remove in the future version. Please use the new attribute 'certificate_name' instead.""")

        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetRouterInterfacesFilterArgs',
    'GetVirtualBorderRoutersFilterArgs',
]

@pulumi.input_type
class GetRouterInterfacesFilterArgs:
    def __init__(__self__, *,
                 key: Optional[str] = None,
                 values: Optional[Sequence[str]] = None):
        if key is not None:
            pulumi.set(__self__, "key", key)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def values(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Optional[Sequence[str]]):
        pulumi.set(self, "values", value)


@pulumi.input_type
class GetVirtualBorderRoutersFilterArgs:
    def __init__(__self__, *,
                 key: Optional[str] = None,
                 values: Optional[Sequence[str]] = None):
        """
        :param str key: The key of the field to filter by, as defined by
               [Alibaba Cloud API](https://www.alibabacloud.com/help/en/doc-detail/124791.htm).
        :param Sequence[str] values: Set of values that are accepted for the given field.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        The key of the field to filter by, as defined by
        [Alibaba Cloud API](https://www.alibabacloud.com/help/en/doc-detail/124791.htm).
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[str]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def values(self) -> Optional[Sequence[str]]:
        """
        Set of values that are accepted for the given field.
        """
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Optional[Sequence[str]]):
        pulumi.set(self, "values", value)


